gegl r1988 - in trunk: . gegl gegl/graph gegl/operation operations/affine operations/color operations/core operations/enhance operations/workshop



Author: ok
Date: Sat Feb  9 21:28:39 2008
New Revision: 1988
URL: http://svn.gnome.org/viewvc/gegl?rev=1988&view=rev

Log:
	xchg get_required_for_output, get_invalidated_by_change (wrong
	way around i previous commit.)

	32 files changed, 232 insertions(+), 200 deletions(-)


Modified:
   trunk/ChangeLog
   trunk/gegl/gegl-plugin.h
   trunk/gegl/graph/gegl-node-context.c
   trunk/gegl/graph/gegl-node.c
   trunk/gegl/operation/gegl-operation-area-filter.c
   trunk/gegl/operation/gegl-operation-composer.c
   trunk/gegl/operation/gegl-operation-filter.c
   trunk/gegl/operation/gegl-operation-sink.c
   trunk/gegl/operation/gegl-operation-source.c
   trunk/gegl/operation/gegl-operation.c
   trunk/gegl/operation/gegl-operation.h
   trunk/gegl/operation/gegl-operations.c
   trunk/operations/affine/affine.c
   trunk/operations/color/remap.c
   trunk/operations/color/stretch-contrast.c
   trunk/operations/core/crop.c
   trunk/operations/core/shift.c
   trunk/operations/enhance/bilateral-filter.c
   trunk/operations/enhance/snn-mean.c
   trunk/operations/workshop/box-percentile.c
   trunk/operations/workshop/c2g.c
   trunk/operations/workshop/demosaic-simple.c
   trunk/operations/workshop/disc-percentile.c
   trunk/operations/workshop/hstack.c
   trunk/operations/workshop/kuwahara-max.c
   trunk/operations/workshop/kuwahara-min.c
   trunk/operations/workshop/kuwahara.c
   trunk/operations/workshop/lens-correct.c
   trunk/operations/workshop/line-profile.c
   trunk/operations/workshop/max-envelope.c
   trunk/operations/workshop/min-envelope.c
   trunk/operations/workshop/snn-percentile.c

Modified: trunk/gegl/gegl-plugin.h
==============================================================================
--- trunk/gegl/gegl-plugin.h	(original)
+++ trunk/gegl/gegl-plugin.h	Sat Feb  9 21:28:39 2008
@@ -53,7 +53,7 @@
  *    should be extended so a range of abi versions are accepted.
  */
 
-#define GEGL_MODULE_ABI_VERSION 0x0006
+#define GEGL_MODULE_ABI_VERSION 0x0007
 
 struct _GeglModuleInfo
 {
@@ -166,16 +166,16 @@
    * graph. A default implementation of this, if not provided should probably
    * be to report that the entire defined region is dirtied.
    */
-  GeglRectangle   (*get_required_for_output)  (GeglOperation       *operation,
+  GeglRectangle   (*get_invalidated_by_change)(GeglOperation        *operation,
                                                const gchar         *input_pad,
                                                const GeglRectangle *input_region);
 
   /* computes the rectangle needed to be correctly computed in a buffer
    * on the named input_pad, for a given result rectangle
    */
-  GeglRectangle   (*get_invalidated_by_change) (GeglOperation       *operation,
-                                                const gchar         *input_pad,
-                                                const GeglRectangle *roi);
+  GeglRectangle   (*get_required_for_output) (GeglOperation        *operation,
+                                              const gchar         *input_pad,
+                                              const GeglRectangle *roi);
 
   /* Adjust result rect, adapts the rectangle used for computing results.
    * (useful for global operations like contrast stretching, as well as
@@ -221,14 +221,14 @@
 /* retrieves the node providing data to a named input pad */
 GeglNode      * gegl_operation_get_source_node           (GeglOperation *operation,
                                                           const gchar   *pad_name);
-GeglRectangle   gegl_operation_get_required_for_output   (GeglOperation *operation,
+GeglRectangle   gegl_operation_get_invalidated_by_change   (GeglOperation *operation,
                                                           const gchar   *input_pad,
                                                           const GeglRectangle *input_region);
 GeglRectangle   gegl_operation_get_bounding_box          (GeglOperation *operation);
 GeglRectangle   gegl_operation_get_cached_region         (GeglOperation *operation,
                                                           const GeglRectangle *roi);
 
-GeglRectangle   gegl_operation_get_invalidated_by_change (GeglOperation *operation,
+GeglRectangle   gegl_operation_get_required_for_output (GeglOperation *operation,
                                                           const gchar   *input_pad,
                                                           const GeglRectangle *roi);
 

Modified: trunk/gegl/graph/gegl-node-context.c
==============================================================================
--- trunk/gegl/graph/gegl-node-context.c	(original)
+++ trunk/gegl/graph/gegl-node-context.c	Sat Feb  9 21:28:39 2008
@@ -368,7 +368,7 @@
  
   node = context->node;
   operation = node->operation;
-  input_request  = gegl_operation_get_invalidated_by_change (
+  input_request  = gegl_operation_get_required_for_output (
                                    operation, padname, &context->need_rect);
 
   real_input = GEGL_BUFFER (gegl_node_context_get_object (context, padname));

Modified: trunk/gegl/graph/gegl-node.c
==============================================================================
--- trunk/gegl/graph/gegl-node.c	(original)
+++ trunk/gegl/graph/gegl-node.c	Sat Feb  9 21:28:39 2008
@@ -534,9 +534,9 @@
   if (destination->operation)
     {
       dirty_rect =
-        gegl_operation_get_required_for_output (destination->operation,
-                                                gegl_pad_get_name (destination_pad),
-                                                rect);
+        gegl_operation_get_invalidated_by_change (destination->operation,
+                                                  gegl_pad_get_name (destination_pad),
+                                                  rect);
     }
   else
     {

Modified: trunk/gegl/operation/gegl-operation-area-filter.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-area-filter.c	(original)
+++ trunk/gegl/operation/gegl-operation-area-filter.c	Sat Feb  9 21:28:39 2008
@@ -35,10 +35,10 @@
 
 static void          prepare                  (GeglOperation       *operation);
 static GeglRectangle get_bounding_box          (GeglOperation       *operation);
-static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
+static GeglRectangle get_required_for_output   (GeglOperation       *operation,
                                                  const gchar         *input_pad,
                                                  const GeglRectangle *region);
-static GeglRectangle get_required_for_output   (GeglOperation       *operation,
+static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
                                                  const gchar         *input_pad,
                                                  const GeglRectangle *input_region);
 
@@ -52,8 +52,8 @@
 
   operation_class->prepare = prepare;
   operation_class->get_bounding_box = get_bounding_box;
-  operation_class->get_required_for_output = get_required_for_output;
   operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 }
 
 static void
@@ -97,9 +97,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *region)
+get_required_for_output (GeglOperation        *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *region)
 {
   GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
   GeglRectangle            rect;
@@ -121,9 +121,9 @@
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *operation,
-                         const gchar         *input_pad,
-                         const GeglRectangle *input_region)
+get_invalidated_by_change (GeglOperation        *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *input_region)
 {
   GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
   GeglRectangle            retval;

Modified: trunk/gegl/operation/gegl-operation-composer.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-composer.c	(original)
+++ trunk/gegl/operation/gegl-operation-composer.c	Sat Feb  9 21:28:39 2008
@@ -56,10 +56,10 @@
                               gint                 x,
                               gint                 y);
 
-static GeglRectangle get_bounding_box          (GeglOperation       *self);
-static GeglRectangle get_invalidated_by_change (GeglOperation       *self,
-                                                 const gchar         *input_pad,
-                                                 const GeglRectangle *roi);
+static GeglRectangle get_bounding_box        (GeglOperation        *self);
+static GeglRectangle get_required_for_output (GeglOperation        *self,
+                                               const gchar         *input_pad,
+                                               const GeglRectangle *roi);
 
 G_DEFINE_TYPE (GeglOperationComposer, gegl_operation_composer,
                GEGL_TYPE_OPERATION)
@@ -78,7 +78,7 @@
   operation_class->attach = attach;
   operation_class->detect = detect;
   operation_class->get_bounding_box = get_bounding_box;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 
   g_object_class_install_property (object_class, PROP_OUTPUT,
                                    g_param_spec_object ("output",
@@ -211,9 +211,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *self,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *self,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   GeglRectangle rect = *roi;
   return rect;

Modified: trunk/gegl/operation/gegl-operation-filter.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-filter.c	(original)
+++ trunk/gegl/operation/gegl-operation-filter.c	Sat Feb  9 21:28:39 2008
@@ -38,12 +38,12 @@
   PROP_INPUT,
 };
 
-static void     get_property            (GObject       *gobject,
+static void     get_property          (GObject       *gobject,
                                          guint          prop_id,
                                          GValue        *value,
                                          GParamSpec    *pspec);
 
-static void     set_property            (GObject       *gobject,
+static void     set_property          (GObject       *gobject,
                                          guint          prop_id,
                                          const GValue  *value,
                                          GParamSpec    *pspec);
@@ -53,13 +53,13 @@
                                          const gchar         *output_prop,
                                          const GeglRectangle *result);
 
-static void     attach                  (GeglOperation *operation);
+static void     attach                 (GeglOperation *operation);
 static GeglNode *detect                 (GeglOperation *operation,
                                          gint           x,
                                          gint           y);
 
 static GeglRectangle get_bounding_box          (GeglOperation       *self);
-static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
+static GeglRectangle get_required_for_output   (GeglOperation       *operation,
                                                  const gchar         *input_pad,
                                                  const GeglRectangle *roi);
 
@@ -76,11 +76,11 @@
   object_class->set_property = set_property;
   object_class->get_property = get_property;
 
-  operation_class->process                   = process;
-  operation_class->attach                    = attach;
-  operation_class->detect                    = detect;
-  operation_class->get_bounding_box          = get_bounding_box;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->process                 = process;
+  operation_class->attach                  = attach;
+  operation_class->detect                  = detect;
+  operation_class->get_bounding_box        = get_bounding_box;
+  operation_class->get_required_for_output = get_required_for_output;
 
   g_object_class_install_property (object_class, PROP_OUTPUT,
                                    g_param_spec_object ("output",
@@ -237,9 +237,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   GeglRectangle result = *roi;
   return result;

Modified: trunk/gegl/operation/gegl-operation-sink.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-sink.c	(original)
+++ trunk/gegl/operation/gegl-operation-sink.c	Sat Feb  9 21:28:39 2008
@@ -43,15 +43,15 @@
                                             const GValue        *value,
                                             GParamSpec          *pspec);
 
-static gboolean      process                   (GeglOperation       *operation,
-                                                 GeglNodeContext     *context,
-                                                 const gchar         *output_prop,
-                                                 const GeglRectangle *result);
-static void          attach                   (GeglOperation       *operation);
-static GeglRectangle get_bounding_box          (GeglOperation       *self);
-static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
-                                                 const gchar         *input_pad,
-                                                 const GeglRectangle *roi);
+static gboolean      process                 (GeglOperation       *operation,
+                                               GeglNodeContext     *context,
+                                               const gchar         *output_prop,
+                                               const GeglRectangle *result);
+static void          attach                 (GeglOperation       *operation);
+static GeglRectangle get_bounding_box        (GeglOperation       *self);
+static GeglRectangle get_required_for_output (GeglOperation       *operation,
+                                               const gchar         *input_pad,
+                                               const GeglRectangle *roi);
 
 
 G_DEFINE_TYPE (GeglOperationSink, gegl_operation_sink, GEGL_TYPE_OPERATION)
@@ -68,10 +68,10 @@
   object_class->set_property = set_property;
   object_class->get_property = get_property;
 
-  operation_class->process               = process;
-  operation_class->attach                = attach;
-  operation_class->get_bounding_box    = get_bounding_box;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->process                 = process;
+  operation_class->attach                  = attach;
+  operation_class->get_bounding_box        = get_bounding_box;
+  operation_class->get_required_for_output = get_required_for_output;
 
   g_object_class_install_property (object_class, PROP_INPUT,
                                    g_param_spec_object ("input",
@@ -156,9 +156,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   GeglRectangle rect=*roi;
   return rect;

Modified: trunk/gegl/operation/gegl-operation-source.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-source.c	(original)
+++ trunk/gegl/operation/gegl-operation-source.c	Sat Feb  9 21:28:39 2008
@@ -51,8 +51,8 @@
 
 G_DEFINE_TYPE (GeglOperationSource, gegl_operation_source, GEGL_TYPE_OPERATION)
 
-static GeglRectangle get_bounding_box          (GeglOperation       *self);
-static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
+static GeglRectangle get_bounding_box          (GeglOperation        *self);
+static GeglRectangle get_required_for_output   (GeglOperation        *operation,
                                                  const gchar         *input_pad,
                                                  const GeglRectangle *roi);
 static GeglRectangle  get_cached_region        (GeglOperation       *operation,
@@ -73,7 +73,7 @@
   operation_class->get_cached_region = get_cached_region;
 
   operation_class->get_bounding_box  = get_bounding_box;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 
   g_object_class_install_property (gobject_class, PROP_OUTPUT,
                                    g_param_spec_object ("output",
@@ -150,9 +150,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   return *roi;
 }

Modified: trunk/gegl/operation/gegl-operation.c
==============================================================================
--- trunk/gegl/operation/gegl-operation.c	(original)
+++ trunk/gegl/operation/gegl-operation.c	Sat Feb  9 21:28:39 2008
@@ -34,15 +34,15 @@
 #include "buffer/gegl-buffer.h"
 #include "gegl-operations.h"
 
-static void          attach                  (GeglOperation       *self);
+static void         attach                    (GeglOperation       *self);
 
-static GeglRectangle get_bounding_box            (GeglOperation       *self);
-static GeglRectangle get_required_for_output     (GeglOperation       *self,
-                                                   const gchar         *input_pad,
-                                                   const GeglRectangle *input_region);
-static GeglRectangle get_invalidated_by_change   (GeglOperation       *self,
-                                                   const gchar         *input_pad,
-                                                   const GeglRectangle *region);
+static GeglRectangle get_bounding_box          (GeglOperation       *self);
+static GeglRectangle get_invalidated_by_change (GeglOperation       *self,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *input_region);
+static GeglRectangle get_required_for_output   (GeglOperation       *self,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *region);
 
 G_DEFINE_TYPE (GeglOperation, gegl_operation, G_TYPE_OBJECT)
 
@@ -60,8 +60,8 @@
   klass->prepare                   = NULL;
   klass->no_cache                  = FALSE;
   klass->get_bounding_box          = get_bounding_box;
-  klass->get_required_for_output   = get_required_for_output;
   klass->get_invalidated_by_change = get_invalidated_by_change;
+  klass->get_required_for_output   = get_required_for_output;
 }
 
 static void
@@ -135,9 +135,9 @@
 }
 
 GeglRectangle
-gegl_operation_get_required_for_output (GeglOperation       *self,
-                                        const gchar         *input_pad,
-                                        const GeglRectangle *input_region)
+gegl_operation_get_invalidated_by_change (GeglOperation        *self,
+                                          const gchar         *input_pad,
+                                          const GeglRectangle *input_region)
 {
   GeglOperationClass *klass;
   GeglRectangle       retval = { 0, };
@@ -152,31 +152,31 @@
       input_region->height == 0)
     return *input_region;
 
-  if (klass->get_required_for_output)
-    return klass->get_required_for_output (self, input_pad, input_region);
+  if (klass->get_invalidated_by_change)
+    return klass->get_invalidated_by_change (self, input_pad, input_region);
 
   return *input_region;
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   GeglRectangle result = *roi;
 
   if (operation->node->is_graph)
     {
-      return gegl_operation_get_invalidated_by_change (operation, input_pad, roi);
+      return gegl_operation_get_required_for_output (operation, input_pad, roi);
     }
 
   return result;
 }
 
 GeglRectangle
-gegl_operation_get_invalidated_by_change (GeglOperation       *operation,
-                                      const gchar         *input_pad,
-                                      const GeglRectangle *roi)
+gegl_operation_get_required_for_output (GeglOperation        *operation,
+                                        const gchar         *input_pad,
+                                        const GeglRectangle *roi)
 {
   GeglOperationClass *klass = GEGL_OPERATION_GET_CLASS (operation);
 
@@ -184,15 +184,15 @@
       roi->height == 0)
     return *roi;
 
-  g_assert (klass->get_invalidated_by_change);
+  g_assert (klass->get_required_for_output);
 
-  return klass->get_invalidated_by_change (operation, input_pad, roi);
+  return klass->get_required_for_output (operation, input_pad, roi);
 }
 
 
 
 GeglRectangle
-gegl_operation_get_cached_region (GeglOperation       *operation,
+gegl_operation_get_cached_region (GeglOperation        *operation,
                                   const GeglRectangle *roi)
 {
   GeglOperationClass *klass = GEGL_OPERATION_GET_CLASS (operation);
@@ -267,8 +267,8 @@
 }
 
 GeglRectangle *
-gegl_operation_source_get_bounding_box (GeglOperation *operation,
-                                          const gchar   *input_pad_name)
+gegl_operation_source_get_bounding_box (GeglOperation  *operation,
+                                        const gchar   *input_pad_name)
 {
   GeglNode *node = gegl_operation_get_source_node (operation, input_pad_name);
 
@@ -279,8 +279,8 @@
 }
 
 void
-gegl_operation_set_source_region (GeglOperation       *operation,
-                                  gpointer             context_id,
+gegl_operation_set_source_region (GeglOperation        *operation,
+                                  gpointer              context_id,
                                   const gchar         *input_pad_name,
                                   const GeglRectangle *region)
 {
@@ -348,13 +348,13 @@
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *self,
-                         const gchar         *input_pad,
-                         const GeglRectangle *input_region)
+get_invalidated_by_change (GeglOperation        *self,
+                           const gchar         *input_pad,
+                           const GeglRectangle *input_region)
 {
   if (self->node->is_graph)
     {
-      return gegl_operation_get_required_for_output (
+      return gegl_operation_get_invalidated_by_change (
                gegl_node_get_output_proxy (self->node, "output")->operation,
                input_pad,
                input_region);

Modified: trunk/gegl/operation/gegl-operation.h
==============================================================================
--- trunk/gegl/operation/gegl-operation.h	(original)
+++ trunk/gegl/operation/gegl-operation.h	Sat Feb  9 21:28:39 2008
@@ -48,78 +48,76 @@
 
 struct _GeglOperationClass
 {
-  GObjectClass  parent_class;
+  GObjectClass    parent_class;
 
-  const gchar  *name;            /* name used to refer to this type of
-                                    operation in GEGL */
-  const gchar  *description;     /* textual description of the operation */
-  const gchar  *categories;      /* a colon seperated list of categories */
+  const gchar    *name;        /* name(string) used to create/indetify
+                                    this type of operation in GEGL*/
+  const gchar    *description; /* textual description of the operation */
+  const gchar    *categories;  /* a colon seperated list of categories */
 
-
-  gboolean          no_cache;    /* do not create a cache for this operation */
+  gboolean        no_cache;    /* do not create a cache for this operation */
 
   /* attach this operation with a GeglNode, override this if you are creating a
    * GeglGraph, it is already defined for Filters/Sources/Composers.
    */
-  void            (*attach)               (GeglOperation *operation);
+  void          (*attach)                    (GeglOperation *operation);
 
   /* prepare() is called on each operation providing data to a node that
    * is requested to provide a rendered result. When prepare is called all
    * properties are known. This is the time to set desired pixel formats
    * for input and output pads.
    */
-  void            (*prepare)              (GeglOperation *operation);
+  void          (*prepare)                   (GeglOperation *operation);
 
   /* Returns the bounding rectangle for the data that is defined by this op.
    * (is already implemented in GeglOperationPointFilter and
    * GeglOperationPointComposer, GeglOperationAreaFilter base classes.
    */
-  GeglRectangle   (*get_bounding_box)   (GeglOperation *operation);
+  GeglRectangle (*get_bounding_box)          (GeglOperation *operation);
 
   /* Computes the region in output (same affected rect assumed for all outputs)
    * when a given region has changed on an input. Used to aggregate dirt in the
    * graph. A default implementation of this, if not provided should probably
    * be to report that the entire defined region is dirtied.
    */
-  GeglRectangle   (*get_required_for_output)  (GeglOperation       *operation,
-                                               const gchar         *input_pad,
-                                               const GeglRectangle *input_region);
-
-  /* computes the rectangle needed to be correctly computed in a buffer
-   * on the named input_pad, for a given result rectangle
-   */
-  GeglRectangle   (*get_invalidated_by_change) (GeglOperation       *operation,
-                                                const gchar         *input_pad,
-                                                const GeglRectangle *roi);
+  GeglRectangle (*get_invalidated_by_change) (GeglOperation       *operation,
+                                              const gchar         *input_pad,
+                                              const GeglRectangle *input_region);
+
+  /* Computes the rectangle needed to be correctly computed in a buffer
+   * on the named input_pad, for a given region of interest.
+   */
+  GeglRectangle (*get_required_for_output)   (GeglOperation       *operation,
+                                              const gchar         *input_pad,
+                                              const GeglRectangle *roi);
 
   /* Adjust result rect, adapts the rectangle used for computing results.
    * (useful for global operations like contrast stretching, as well as
    * file loaders to force caching of the full raster).
    */
-  GeglRectangle   (*get_cached_region)         (GeglOperation       *operation,
-                                                const GeglRectangle *roi);
+  GeglRectangle (*get_cached_region)         (GeglOperation       *operation,
+                                              const GeglRectangle *roi);
+
+  /* Perform processing for the @output_pad, pad The result_rect provides the
+   * region to process. For sink operations @output_pad can be ignored but the
+   * result_rect is then then indicating the data available for consumption.
+   */
+  gboolean      (*process)                   (GeglOperation       *operation,
+                                              GeglNodeContext     *context,
+                                              const gchar         *output_pad,
+                                              const GeglRectangle *result_rect);
 
   /* XXX: What is GeglNode doing in this part of the API?
    * Returns the node providing data for a specific location within the
-   * operations output. Does this recurse?, perhaps it should only point
-   * out which pad the data is coming from?
+   * operations output. Does this recurse?, perhaps it should only point out
+   * which pad the data is coming from?
    */
-  GeglNode*       (*detect)                (GeglOperation       *operation,
-                                            gint                 x,
-                                            gint                 y);
-
-  /* Perform processing for the @output_pad, pad The result_rect provides
-   * the region to process. For sink operations @output_pad can be ignored
-   * but the result_rect is then then indicating the data available for
-   * consumption.
-   */
-  gboolean        (*process)               (GeglOperation       *operation,
-                                            GeglNodeContext     *context,
-                                            const gchar         *output_pad,
-                                            const GeglRectangle *result_rect);
+  GeglNode*     (*detect)                    (GeglOperation       *operation,
+                                              gint                 x,
+                                              gint                 y);
 };
 
-GType           gegl_operation_get_type             (void) G_GNUC_CONST;
+GType           gegl_operation_get_type        (void) G_GNUC_CONST;
 
 /* retrieves the bounding box of a connected input */
 GeglRectangle * gegl_operation_source_get_bounding_box (GeglOperation *operation,
@@ -136,14 +134,14 @@
 /* retrieves the node providing data to a named input pad */
 GeglNode      * gegl_operation_get_source_node         (GeglOperation *operation,
                                                         const gchar   *pad_name);
-GeglRectangle   gegl_operation_get_required_for_output (GeglOperation *operation,
+GeglRectangle   gegl_operation_get_invalidated_by_change (GeglOperation *operation,
                                                         const gchar   *input_pad,
                                                         const GeglRectangle *input_region);
 GeglRectangle   gegl_operation_get_bounding_box        (GeglOperation *operation);
 GeglRectangle   gegl_operation_get_cached_region       (GeglOperation *operation,
                                                         const GeglRectangle *roi);
 
-GeglRectangle   gegl_operation_get_invalidated_by_change(GeglOperation *operation,
+GeglRectangle   gegl_operation_get_required_for_output(GeglOperation *operation,
                                                          const gchar   *input_pad,
                                                          const GeglRectangle *roi);
 

Modified: trunk/gegl/operation/gegl-operations.c
==============================================================================
--- trunk/operations/affine/affine.c	(original)
+++ trunk/operations/affine/affine.c	Sat Feb  9 21:28:39 2008
@@ -61,10 +61,10 @@
 static void          get_source_matrix       (OpAffine            *affine,
                                               Matrix3              output);
 static GeglRectangle get_bounding_box       (GeglOperation       *op);
-static GeglRectangle get_required_for_output (GeglOperation       *operation,
+static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
                                               const gchar         *input_pad,
                                               const GeglRectangle *input_region);
-static GeglRectangle get_invalidated_by_change(GeglOperation       *self,
+static GeglRectangle get_required_for_output(GeglOperation       *self,
                                               const gchar         *input_pad,
                                               const GeglRectangle *region);
 
@@ -140,9 +140,9 @@
   gobject_class->set_property = set_property;
   gobject_class->get_property = get_property;
 
-  op_class->get_required_for_output = get_required_for_output;
-  op_class->get_bounding_box  = get_bounding_box;
   op_class->get_invalidated_by_change = get_invalidated_by_change;
+  op_class->get_bounding_box = get_bounding_box;
+  op_class->get_required_for_output = get_required_for_output;
   op_class->detect = detect;
   op_class->categories = "transform";
   op_class->prepare = prepare;
@@ -449,9 +449,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *op,
-                           const gchar         *input_pad,
-                           const GeglRectangle *region)
+get_required_for_output (GeglOperation       *op,
+                         const gchar         *input_pad,
+                         const GeglRectangle *region)
 {
   OpAffine      *affine = (OpAffine *) op;
   Matrix3        inverse;
@@ -511,9 +511,9 @@
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation        *op,
-                         const gchar         *input_pad,
-                         const GeglRectangle *input_region)
+get_invalidated_by_change (GeglOperation        *op,
+                           const gchar         *input_pad,
+                           const GeglRectangle *input_region)
 {
   OpAffine      *affine  = (OpAffine *) op;
   OpAffineClass *klass   = OP_AFFINE_GET_CLASS (affine);

Modified: trunk/operations/color/remap.c
==============================================================================
--- trunk/operations/color/remap.c	(original)
+++ trunk/operations/color/remap.c	Sat Feb  9 21:28:39 2008
@@ -91,17 +91,17 @@
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *operation,
-                         const gchar         *input_pad,
-                         const GeglRectangle *input_region)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *input_region)
 {
   return *input_region;
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation       *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   return *roi;
 }
@@ -180,8 +180,8 @@
   operation_class->prepare = prepare;
   operation_class->detect  = detect;
   operation_class->get_bounding_box = get_bounding_box;
-  operation_class->get_required_for_output = get_required_for_output;
   operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 
   operation_class->name        = "remap";
   operation_class->categories  = "color";

Modified: trunk/operations/color/stretch-contrast.c
==============================================================================
--- trunk/operations/color/stretch-contrast.c	(original)
+++ trunk/operations/color/stretch-contrast.c	Sat Feb  9 21:28:39 2008
@@ -83,9 +83,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   GeglRectangle result = *gegl_operation_source_get_bounding_box (operation, "input");
   return result;
@@ -144,7 +144,7 @@
 
   filter_class->process = process;
   operation_class->prepare = prepare;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 
   operation_class->name        = "stretch-contrast";
   operation_class->categories  = "color:enhance";

Modified: trunk/operations/core/crop.c
==============================================================================
--- trunk/operations/core/crop.c	(original)
+++ trunk/operations/core/crop.c	Sat Feb  9 21:28:39 2008
@@ -70,7 +70,7 @@
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *operation,
+get_invalidated_by_change (GeglOperation       *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *input_region)
 {
@@ -83,9 +83,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation       *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   return *roi;
 }
@@ -139,9 +139,9 @@
   operation_class->process = process;
   operation_class->get_bounding_box = get_bounding_box;
   operation_class->detect = detect;
-  operation_class->get_required_for_output = get_required_for_output;
-  operation_class->get_bounding_box = get_bounding_box;
   operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_required_for_output = get_required_for_output;
 
   operation_class->name        = "crop";
   operation_class->categories  = "core";

Modified: trunk/operations/core/shift.c
==============================================================================
--- trunk/operations/core/shift.c	(original)
+++ trunk/operations/core/shift.c	Sat Feb  9 21:28:39 2008
@@ -80,9 +80,9 @@
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *operation,
-                         const gchar         *input_pad,
-                         const GeglRectangle *input_region)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *input_region)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = *input_region;
@@ -94,9 +94,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation       *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = *roi;
@@ -169,8 +169,8 @@
   operation_class->attach                  = attach;
   operation_class->detect                  = detect;
   operation_class->get_bounding_box      = get_bounding_box;
-  operation_class->get_invalidated_by_change   = get_invalidated_by_change;
-  operation_class->get_required_for_output = get_required_for_output;
+  operation_class->get_required_for_output   = get_required_for_output;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   operation_class->name        = "shift";
   operation_class->categories  = "core";

Modified: trunk/operations/enhance/bilateral-filter.c
==============================================================================
--- trunk/operations/enhance/bilateral-filter.c	(original)
+++ trunk/operations/enhance/bilateral-filter.c	Sat Feb  9 21:28:39 2008
@@ -61,8 +61,7 @@
   GeglBuffer   *temp_in;
   GeglRectangle compute;
 
-  compute = gegl_operation_get_invalidated_by_change (
-                   operation, "input", result);
+  compute = gegl_operation_get_required_for_output (operation, "input",result);
 
   if (o->blur_radius < 1.0)
     {

Modified: trunk/operations/enhance/snn-mean.c
==============================================================================
--- trunk/operations/enhance/snn-mean.c	(original)
+++ trunk/operations/enhance/snn-mean.c	Sat Feb  9 21:28:39 2008
@@ -59,7 +59,7 @@
   GeglBuffer          *temp_in;
   GeglRectangle        compute;
 
-  compute  = gegl_operation_get_invalidated_by_change (
+  compute  = gegl_operation_get_required_for_output (
                    operation, "input", result);
 
   if (o->radius < 1.0)

Modified: trunk/operations/workshop/box-percentile.c
==============================================================================
--- trunk/operations/workshop/box-percentile.c	(original)
+++ trunk/operations/workshop/box-percentile.c	Sat Feb  9 21:28:39 2008
@@ -58,7 +58,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/c2g.c
==============================================================================
--- trunk/operations/workshop/c2g.c	(original)
+++ trunk/operations/workshop/c2g.c	Sat Feb  9 21:28:39 2008
@@ -71,7 +71,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/demosaic-simple.c
==============================================================================
--- trunk/operations/workshop/demosaic-simple.c	(original)
+++ trunk/operations/workshop/demosaic-simple.c	Sat Feb  9 21:28:39 2008
@@ -118,7 +118,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/disc-percentile.c
==============================================================================
--- trunk/operations/workshop/disc-percentile.c	(original)
+++ trunk/operations/workshop/disc-percentile.c	Sat Feb  9 21:28:39 2008
@@ -34,9 +34,9 @@
 #include <math.h>
 
 static void median (GeglBuffer *src,
-                    GeglBuffer *dst,
-                    gint        radius,
-                    gdouble     rank);
+                      GeglBuffer *dst,
+                      gint        radius,
+                      gdouble     rank);
 
 #include <stdio.h>
 
@@ -190,7 +190,7 @@
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
   GeglRectangle compute =
-        gegl_operation_get_invalidated_by_change (operation, "input", result);
+        gegl_operation_get_required_for_output (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/hstack.c
==============================================================================
--- trunk/operations/workshop/hstack.c	(original)
+++ trunk/operations/workshop/hstack.c	Sat Feb  9 21:28:39 2008
@@ -58,7 +58,7 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *self,
+get_required_for_output (GeglOperation       *self,
                        const gchar         *input_pad,
                        const GeglRectangle *roi)
 {
@@ -82,9 +82,9 @@
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *self,
-                         const gchar         *input_pad,
-                         const GeglRectangle *region)
+get_invalidated_by_change (GeglOperation       *self,
+                           const gchar         *input_pad,
+                           const GeglRectangle *region)
 {
   if (!strcmp ("input_pad", "input"))
     {
@@ -164,8 +164,8 @@
   composer_class->process = process;
   operation_class->prepare = prepare;
   operation_class->get_bounding_box = get_bounding_box;
-  operation_class->get_required_for_output = get_required_for_output;
   operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 
   operation_class->name        = "hstack";
   operation_class->categories  = "misc";

Modified: trunk/operations/workshop/kuwahara-max.c
==============================================================================
--- trunk/operations/workshop/kuwahara-max.c	(original)
+++ trunk/operations/workshop/kuwahara-max.c	Sat Feb  9 21:28:39 2008
@@ -207,7 +207,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/kuwahara-min.c
==============================================================================
--- trunk/operations/workshop/kuwahara-min.c	(original)
+++ trunk/operations/workshop/kuwahara-min.c	Sat Feb  9 21:28:39 2008
@@ -207,7 +207,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/kuwahara.c
==============================================================================
--- trunk/operations/workshop/kuwahara.c	(original)
+++ trunk/operations/workshop/kuwahara.c	Sat Feb  9 21:28:39 2008
@@ -207,7 +207,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/lens-correct.c
==============================================================================
--- trunk/operations/workshop/lens-correct.c	(original)
+++ trunk/operations/workshop/lens-correct.c	Sat Feb  9 21:28:39 2008
@@ -326,14 +326,14 @@
 /* Compute the input rectangle required to compute the specified region of interest (roi).
  */
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                           const gchar         *input_pad,
-                           const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *operation,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   GeglChantO   *area = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = *gegl_operation_source_get_bounding_box (operation, "input");
   #ifdef TRACE
-    g_warning ("> get_invalidated_by_change src=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
+    g_warning ("> get_required_for_output src=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
     if (roi)
       g_warning ("  ROI == %dx%d+%d+%d", roi->width, roi->height, roi->x, roi->y);
   #endif
@@ -343,7 +343,7 @@
     result.height++;
   }
   #ifdef TRACE
-    g_warning ("< get_invalidated_by_change res=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
+    g_warning ("< get_required_for_output res=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
   #endif
   return result;
 }
@@ -391,7 +391,7 @@
   filter_class->process = process;
   operation_class->prepare = prepare;
   operation_class->get_bounding_box = get_bounding_box;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 
   operation_class->name        = "lens-correct";
   operation_class->categories  = "blur";

Modified: trunk/operations/workshop/line-profile.c
==============================================================================
--- trunk/operations/workshop/line-profile.c	(original)
+++ trunk/operations/workshop/line-profile.c	Sat Feb  9 21:28:39 2008
@@ -133,9 +133,9 @@
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *self,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_required_for_output (GeglOperation        *self,
+                         const gchar         *input_pad,
+                         const GeglRectangle *roi)
 {
   return *gegl_operation_source_get_bounding_box (self, "input");
 }
@@ -162,7 +162,7 @@
   filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
 
   filter_class->process = process;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
   operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "line-profile";

Modified: trunk/operations/workshop/max-envelope.c
==============================================================================
--- trunk/operations/workshop/max-envelope.c	(original)
+++ trunk/operations/workshop/max-envelope.c	Sat Feb  9 21:28:39 2008
@@ -103,7 +103,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/min-envelope.c
==============================================================================
--- trunk/operations/workshop/min-envelope.c	(original)
+++ trunk/operations/workshop/min-envelope.c	Sat Feb  9 21:28:39 2008
@@ -103,7 +103,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute  = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute  = gegl_operation_get_required_for_output (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/snn-percentile.c
==============================================================================
--- trunk/operations/workshop/snn-percentile.c	(original)
+++ trunk/operations/workshop/snn-percentile.c	Sat Feb  9 21:28:39 2008
@@ -228,7 +228,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute  = gegl_operation_get_invalidated_by_change (operation, "input", result);
+  GeglRectangle compute  = gegl_operation_get_required_for_output (operation, "input", result);
 
   if (result->width == 0 ||
       result->height== 0 ||



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/gegl/operation/gegl-operations.c	(original)
+++ trunk/gegl/operation/gegl-operations.c	Sat Feb  9 21:28:39 2008
@@ -135,12 +135,12 @@
   context = gegl_node_get_context (operation->node, context_id);
   request = context->need_rect;
 
   /* for each input, get_invalidated_by_change use gegl_operation_set_source_region() */
   for (input_pads = operation->node->input_pads;input_pads;input_pads=input_pads->next)
     {
       const gchar *pad_name = gegl_pad_get_name (input_pads->data);
       GeglRectangle rect;
-      rect = gegl_operation_get_invalidated_by_change (operation, pad_name, &request); 
+      rect = gegl_operation_get_required_for_output (operation, pad_name, &request); 
 
       gegl_operation_set_source_region (operation, context_id, pad_name, &rect);
     }
@@ -135,12 +135,12 @@
   request = context->need_rect;
 
-  /* for each input, get_invalidated_by_change use gegl_operation_set_source_region() */
+  /* for each input, get_required_for_output use gegl_operation_set_source_region() */
   for (input_pads = operation->node->input_pads;input_pads;input_pads=input_pads->next)
     {

Modified: trunk/operations/affine/affine.c
==============================================================================